Struct rustc_mir::transform::type_check::Locations
[−]
[src]
pub struct Locations {
pub from_location: Location,
pub at_location: Location,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Fields
from_location: Location
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The location in the MIR that generated these constraints. This is intended for error reporting and diagnosis; the constraints may take effect at a distinct spot.
at_location: Location
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The constraints must be met at this location. In terms of the
NLL RFC, when you have a constraint R1: R2 @ P, this field
is the P value.